pub trait BlockModelGenerator {
// Required method
fn write_to_mesh(&self, mesh: &mut TempMesh, pos: IVec3);
}Expand description
A generator for creating a block model that can be written to a temporary chunk mesh.
Required Methods
Sourcefn write_to_mesh(&self, mesh: &mut TempMesh, pos: IVec3)
fn write_to_mesh(&self, mesh: &mut TempMesh, pos: IVec3)
Writes the block model to the provided temporary chunk mesh.