BlockModelGenerator

Trait BlockModelGenerator 

pub trait BlockModelGenerator {
    // Required method
    fn write_to_mesh(&self, mesh: &mut TempMesh, pos: IVec3);
}
A generator for creating a block model that can be written to a temporary chunk mesh.

Required Methods

fn write_to_mesh(&self, mesh: &mut TempMesh, pos: IVec3)

Writes the block model to the provided temporary chunk mesh.

Implementors